"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@nestjs/core");
const common_1 = require("@nestjs/common");
const config = require("config");
const swagger_1 = require("@nestjs/swagger");
const cookieParser = require("cookie-parser");
const nest_winston_1 = require("nest-winston");
const app_module_1 = require("./app.module");
const compression = require("compression");
const env_config_1 = require("./config/env.config");
const path_1 = require("path");
async function bootstrap() {
    const serverConfig = config.get('server');
    const port = serverConfig.port;
    const app = await core_1.NestFactory.create(app_module_1.AppModule);
    app.useStaticAssets((0, path_1.join)(__dirname, '..', 'public'));
    app.setGlobalPrefix('api');
    app.use(compression());
    app.set('trust proxy', 1);
    app.disable('x-powered-by');
    app.useLogger(app.get(nest_winston_1.WINSTON_MODULE_NEST_PROVIDER));
    app.useGlobalInterceptors(new common_1.ClassSerializerInterceptor(app.get(core_1.Reflector)));
    const apiConfig = config.get('app');
    if (env_config_1.NODE_ENV === 'development') {
        app.enableCors({
            origin: true,
            methods: 'GET,HEAD,PUT,PATCH,POST,DELETE,OPTIONS',
            credentials: true,
        });
        const swaggerConfig = new swagger_1.DocumentBuilder()
            .setTitle(apiConfig.name)
            .setDescription(apiConfig.description)
            .setVersion(apiConfig.version)
            .addBearerAuth()
            .build();
        const customOptions = {
            swaggerOptions: {
                persistAuthorization: true,
            },
            customSiteTitle: apiConfig.description,
        };
        const document = swagger_1.SwaggerModule.createDocument(app, swaggerConfig);
        swagger_1.SwaggerModule.setup('api-docs', app, document, customOptions);
    }
    else {
        const whitelist = [apiConfig.get('frontendUrl')];
        app.enableCors({
            origin: function (origin, callback) {
                if (!origin || whitelist.indexOf(origin) !== -1) {
                    callback(null, true);
                }
                else {
                    callback(new Error('Not allowed by CORS'));
                }
            },
            credentials: true,
        });
    }
    app.useGlobalPipes(new common_1.ValidationPipe({}));
    app.use(cookieParser());
    await app.listen(process.env.PORT || port);
    console.log(`Application listening in port: ${process.env.PORT || port}`);
}
bootstrap();
//# sourceMappingURL=main.js.map