"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminService = void 0;
const common_1 = require("@nestjs/common");
const jwt_utilities_1 = require("../../common/helpers/utilities/jwt.utilities");
const typeorm_1 = require("typeorm");
const admin_entity_1 = require("../../models/admin.entity");
const bcrypt = require("bcrypt");
let AdminService = class AdminService {
    constructor(adminRepository) {
        this.adminRepository = adminRepository;
    }
    async register(payload) {
        const account = await this.adminRepository.findOne({
            where: {
                email: payload.email,
            },
        });
        if (account) {
            throw new common_1.BadRequestException('Email address already exist');
        }
        const randomNumber = Math.floor(Math.random() * (9999 - 1000 + 1)) + 1000;
        await this.adminRepository.save({
            name: payload.name,
            email: payload.email.toLowerCase(),
            verification_token: randomNumber.toString(),
            password: payload.password ? bcrypt.hashSync(payload.password, 8) : null,
            phone: payload.phone,
            status: admin_entity_1.AdminStatusEnum.ACTIVE,
        });
        return;
    }
    async verifyRegistration(body) {
        const user = await this.adminRepository.findOne({
            where: {
                email: body.email,
            },
        });
        if (!user) {
            throw new common_1.BadRequestException('User does not exist');
        }
        if (user.status != admin_entity_1.AdminStatusEnum.INACTIVE) {
            throw new common_1.BadRequestException('Account has been verified');
        }
        await this.adminRepository.update({
            id: user.id,
        }, {
            status: admin_entity_1.AdminStatusEnum.ACTIVE,
            verification_token: null,
        });
        return;
    }
    async login(payload) {
        const admin = await this.adminRepository.findOne({
            where: {
                email: payload.email,
            },
        });
        if (!admin) {
            throw new common_1.BadRequestException('Invalid credentials');
        }
        if (admin.status != admin_entity_1.AdminStatusEnum.ACTIVE) {
            throw new common_1.BadRequestException('The account has not been activated');
        }
        if (!(admin && bcrypt.compareSync(payload.password, admin.password))) {
            throw new common_1.BadRequestException('Invalid credentials');
        }
        return {
            data: {
                token: await jwt_utilities_1.JwtUtilities.adminSignToken(admin),
                admin: admin,
            },
        };
    }
    async update(payload, admin) {
        const data = {};
        if (payload.name) {
            data['name'] = payload.name;
        }
        if (payload.phone) {
            data['phone'] = payload.phone;
        }
        await this.adminRepository.update({
            id: admin.id,
        }, data);
        return;
    }
    async startResetPassword(data) {
        const account = await this.adminRepository.findOne({
            where: {
                email: data.email,
                status: admin_entity_1.AdminStatusEnum.ACTIVE,
            },
        });
        if (!account) {
            throw new common_1.BadRequestException('Email address does not exist');
        }
        const randomNumber = Math.floor(Math.random() * (9999 - 1000 + 1)) + 1000;
        await this.adminRepository.update({
            id: account.id,
        }, {
            verification_token: randomNumber.toString(),
        });
        return;
    }
    async resetPassword(body) {
        const admin = await this.adminRepository.findOne({
            where: {
                email: body.email,
                status: (0, typeorm_1.Not)(admin_entity_1.AdminStatusEnum.BLOCKED),
            },
        });
        if (!admin) {
            throw new common_1.BadRequestException('Account does not exist');
        }
        if (admin.verification_token != body.token) {
            throw new common_1.BadRequestException('Token is invalid');
        }
        await this.adminRepository.update({
            id: admin.id,
        }, {
            password: bcrypt.hashSync(body.password, 8),
            verification_token: null,
            status: admin_entity_1.AdminStatusEnum.ACTIVE,
        });
        return;
    }
    async changePassword(payload, admin) {
        const account = await this.adminRepository.findOne({
            where: {
                id: admin.id,
            },
        });
        if (!bcrypt.compareSync(payload.old_password, account.password)) {
            throw new common_1.BadRequestException('Wrong old password');
        }
        await this.adminRepository.update({
            id: admin.id,
        }, {
            password: bcrypt.hashSync(payload.password, 8),
            verification_token: null,
            status: admin_entity_1.AdminStatusEnum.ACTIVE,
        });
        return;
    }
    async getAll() {
        const users = await this.adminRepository.find();
        return {
            data: users,
        };
    }
    async delete(id) {
        await this.adminRepository.softDelete({
            id,
        });
        return;
    }
    async getOne(id) {
        const role = await this.adminRepository.findOne({
            where: {
                id,
            },
        });
        if (!role) {
            throw new common_1.NotFoundException('Invalid admin');
        }
        return role;
    }
    async deleteById(provider_id) {
        await this.adminRepository.softDelete({
            id: provider_id,
        });
        return;
    }
};
AdminService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)('ADMIN_REPOSITORY')),
    __metadata("design:paramtypes", [typeorm_1.Repository])
], AdminService);
exports.AdminService = AdminService;
//# sourceMappingURL=admin.service.js.map