"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwardService = void 0;
const user_service_1 = require("./../user/user.service");
const common_1 = require("@nestjs/common");
const typeorm_1 = require("typeorm");
let AwardService = class AwardService {
    constructor(awardRepository, userAwardRepository, userService) {
        this.awardRepository = awardRepository;
        this.userAwardRepository = userAwardRepository;
        this.userService = userService;
    }
    async getAll(user) {
        const awards = await this.awardRepository.find();
        const array = [];
        for (let i = 0; i < awards.length; i++) {
            const award = awards[i];
            award['userAwards'] = await this.userAwardRepository.find({
                where: {
                    award: {
                        id: award.id,
                    },
                    createdBy: {
                        id: user.id,
                    },
                },
                relations: ['user'],
            });
            array.push(award);
        }
        return array;
    }
    async getAllV2() {
        const awards = await this.awardRepository.find();
        const array = [];
        for (let i = 0; i < awards.length; i++) {
            const award = awards[i];
            const userAwards = await this.userAwardRepository.find({
                where: {
                    award: {
                        id: award.id,
                    },
                },
                relations: ['user'],
            });
            const result = [];
            userAwards.reduce((res, value) => {
                if (!res[value.user.id]) {
                    res[value.user.id] = {
                        score: 0,
                        user: value.user,
                    };
                    result.push(res[value.user.id]);
                }
                res[value.user.id].score = res[value.user.id].score + 1;
                return res;
            }, {});
            result.sort((a, b) => b.score - a.score);
            award['userAwards'] = result.slice(0, 3);
            array.push(award);
        }
        return array;
    }
    async add(payload) {
        try {
            await this.awardRepository.save(Object.assign({}, payload));
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async update(id, payload) {
        try {
            const award = await this.awardRepository.findOne({
                where: {
                    id: id,
                },
            });
            if (payload.can_nominate != null) {
                award.can_nominate = payload.can_nominate;
            }
            if (payload.title) {
                award.title = payload.title;
            }
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async addNominee(payload, user) {
        try {
            const award = await this.awardRepository.findOne({
                where: {
                    id: payload.awardId,
                },
            });
            if (!award.can_nominate) {
                throw new common_1.InternalServerErrorException('You cannot nominate someone');
            }
            await this.userAwardRepository.delete({
                award: {
                    id: payload.awardId,
                },
                createdBy: {
                    id: user.id,
                },
            });
            const nominatedUser = await this.userService.getOne(payload.userId);
            await this.userAwardRepository.save({
                award: award,
                user: nominatedUser,
                createdBy: user,
            });
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async delete(id) {
        await this.awardRepository.softDelete({
            id: id,
        });
        return;
    }
};
AwardService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)('AWARD_REPOSITORY')),
    __param(1, (0, common_1.Inject)('USER_AWARD_REPOSITORY')),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        typeorm_1.Repository,
        user_service_1.UserService])
], AwardService);
exports.AwardService = AwardService;
//# sourceMappingURL=award.service.js.map