"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QuestionService = void 0;
const common_1 = require("@nestjs/common");
const typeorm_1 = require("typeorm");
const moment = require("moment");
let QuestionService = class QuestionService {
    constructor(questiondRepository, opionsRepository, userScoreRepository) {
        this.questiondRepository = questiondRepository;
        this.opionsRepository = opionsRepository;
        this.userScoreRepository = userScoreRepository;
    }
    async getAll(user) {
        const today = moment().format('YYYY-MM-DD HH:mm:ss');
        const userScores = await this.userScoreRepository.find({
            where: {
                user: { id: user.id },
            },
        });
        for (let i = 0; i < userScores.length; i++) {
            const userDate = moment(userScores[i].date).format('YYYY-MM-DD HH:mm:ss');
            if (moment(userDate).isSame(moment(), 'day')) {
                const questions = await this.questiondRepository
                    .createQueryBuilder('question')
                    .where(`'${userDate}'  BETWEEN question.startDate AND question.endDate`)
                    .getMany();
                if (questions.length > 0) {
                    return [];
                }
            }
        }
        return await this.questiondRepository
            .createQueryBuilder('question')
            .leftJoinAndSelect('question.options', 'options')
            .where(`'${today}'  BETWEEN question.startDate AND question.endDate`)
            .getMany();
    }
    async add(payload) {
        try {
            const question = await this.questiondRepository.save(Object.assign({}, payload));
            if (payload.options.length > 0) {
                for (let i = 0; i < payload.options.length; i++) {
                    await this.opionsRepository.save({
                        title: payload.options[i].title,
                        question,
                    });
                }
            }
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async update(id, payload) {
        try {
            const question = await this.questiondRepository.findOne({
                where: {
                    id,
                },
            });
            if (payload.title) {
                question.title = payload.title;
            }
            if (payload.startDate) {
                question.startDate = payload.startDate;
            }
            if (payload.endDate) {
                question.endDate = payload.endDate;
            }
            await this.questiondRepository.update({
                id: payload.id,
            }, question);
            if (payload.options) {
                await this.opionsRepository.delete({
                    question: {
                        id: question.id,
                    },
                });
                if (payload.options.length > 0) {
                    for (let i = 0; i < payload.options.length; i++) {
                        await this.opionsRepository.save({
                            title: payload.options[i].title,
                            question,
                        });
                    }
                }
            }
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async addAnswerToQuestion(questionId, answerId) {
        try {
            const question = await this.questiondRepository.findOne({
                where: {
                    id: questionId,
                },
            });
            if (question) {
                const option = await this.opionsRepository.findOne({
                    where: {
                        id: answerId,
                        question: {
                            id: question.id,
                        },
                    },
                });
                question.answer = option;
                question.save();
            }
        }
        catch (error) {
            throw new common_1.InternalServerErrorException(error.message);
        }
        return;
    }
    async getScoreCard() {
        const scoreCards = await this.userScoreRepository.find({
            relations: ['user'],
        });
        const result = [];
        scoreCards.reduce((res, value) => {
            if (!res[value.user.id]) {
                res[value.user.id] = {
                    score: 0,
                    user: value.user,
                };
                result.push(res[value.user.id]);
            }
            res[value.user.id].score = res[value.user.id].score + 1;
            return res;
        }, {});
        result.sort((a, b) => b.score - a.score);
        return result;
    }
    async answers(payload, user) {
        const todayDate = new Date();
        let score = 0;
        let answer;
        for (let i = 0; i < payload.answers.length; i++) {
            answer = payload.answers[i];
            if (answer.questionId && answer.answerId) {
                const question = await this.questiondRepository.findOne({
                    where: {
                        id: answer.questionId,
                        answer: {
                            id: answer.answerId,
                        },
                    },
                });
                if (question) {
                    score++;
                }
            }
        }
        this.userScoreRepository.save({
            score,
            user,
            date: todayDate,
        });
    }
    async delete(id) {
        await this.questiondRepository.softDelete({
            id,
        });
        return;
    }
};
QuestionService = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)('QUESTION_REPOSITORY')),
    __param(1, (0, common_1.Inject)('OPTIONS_REPOSITORY')),
    __param(2, (0, common_1.Inject)('SCORE_REPOSITORY')),
    __metadata("design:paramtypes", [typeorm_1.Repository,
        typeorm_1.Repository,
        typeorm_1.Repository])
], QuestionService);
exports.QuestionService = QuestionService;
//# sourceMappingURL=question.service.js.map